/*******************
VARIABLES
*******************/
var creativeId = "Banner"; //Use anything that uniquely identifies this creative
var creativeVersion = "2.0.10";
var lastModified = "2017-08-09";
var lastUploaded = "2017-08-09";
var templateVersion = "2.0.30";

var sdkData, adId, rnd, uid;

var banner;
var clickThroughObject;
var contentObject;
var logoObject;
var parallaxObject;
var parallaxObject2;
var aParallax = [];
var timeout;

/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	try {
		if(window.localPreview) {
			window.initializeLocalPreview(); //in localPreview.js
			initializeCreative();
			return;
		}
	} catch(e) {console.log(e)}

	adkit.onReady(initializeCreative);
}

function initializeCreative(event) {
//	console.log('initializeCreative')
	// so messaging can work in safe frames we need to bind the events that are present in the event manager.
	EBG.pm.bind("sendCreativeId", function () {
		eventManager.apply(this, arguments);
	}, this);
	EBG.pm.bind("eventCallback", function () {
		eventManager.apply(this, arguments);
	}, this);
	
	EB.Comm = EB.Comm || new EBG.Comm();
	EB.Comm.setName("banner");

	//Workaround (from QB6573) for Async EB Load where Modernizr isn't properly initialized
	typeof Modernizr == "object" && (Modernizr.touch = Modernizr.touch || "ontouchstart" in window);

	initializeGlobalVariables();
	window.registerInteraction = function () {}; //overwrite rI function because it will never actually be called
	addEventListeners();

	setCreativeVersion();
}

function initializeGlobalVariables() {
//	console.log('initializeGlobalVariables')
	sdkData = EB.getSDKData();
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;

	banner = document.getElementById("banner");
	clickThroughObject = document.getElementById("clickthrough");
	contentObject = document.getElementById("contentObject");
	logoObject = document.getElementById("logo");
	parallaxObject = document.getElementById("parallaxObject");
	parallaxObject2 = document.getElementById("parallaxObject2");
	
	setPRConfiguration({});
	
	// set parallax reveal callback (optional)
	setPRCallback({
		name: "hideObject",
		y1: "0%",
		y2: "30%"
	});
	setPRCallback({
		name: "showObject",
		y1: "31%",
		y2: "69%"
	});
	setPRCallback({
		name: "hideObject",
		y1: "70%",
		y2: "100%"
	});
	parallax(parallaxObject, 'left', '-20%', '120%');
	parallax(parallaxObject2, 'left', '-60%', '140%');
	
	// resize event listener calls responsiveAdContents to adjust banner upon resize.
	window.addEventListener("resize", responsiveAdContents, false);
	
	// start ad
	startCreative();
	
	timeout = setTimeout(gracefulFail, 100);
}

function addEventListeners() {
	clickThroughObject.addEventListener("click", handleClickthrough, false);
}

function handleClickthrough() {
	EB.clickthrough();
}

function registerInteraction() {
	//Register your automatic and user interactions here and the platform will parse them on workspace upload. This function will not be called.
	//Example: 'Left_Gutter_Viewed'
	//EB.automaticEventCounter("interactionName1");
	//EB.userActionCounter("userActionName2");
}

function startCreative() {
	var isMRAID = sdkData!==null && sdkData.SDKType==="MRAID";
	if (isMRAID) { setTimeout(showObject, 1000); }
//	console.log('startCreative (isMRAID', isMRAID+')')
	
	//Put here any code you want to execute when the ad is all ready.
}

function showObject(e) {
	EB.API.setStyle(clickthrough, {
		left: 0
	});
}

function hideObject(e) {
	EB.API.setStyle(clickthrough, {
		left: '-100%'
	});
}

function responsiveAdContents() {
//	console.log('responsiveAdContents', window.innerWidth, 'x', window.innerHeight);	
	banner.style.height = window.innerHeight + "px";
}

function gracefulFail() {
	showObject();
	
	var staticBG = document.createElement('div');
		staticBG.setAttribute('id', 'staticBG');
		staticBG.style.background = "#000000 url(images/background1.jpg) no-repeat center center / cover";
	banner.appendChild(staticBG);
	
//	console.log('gracefulFail', staticBG)
}
function revertFromGracefulFail() {
	if (document.getElementById('staticBG')) {
		hideObject();

		banner.removeChild(document.getElementById('staticBG'));

	//	console.log('revertFromGracefulFail')
	}
}
/*************************************************************************************/
/* libraries below, please do not change unless you are 100% sure what you are doing */
/*************************************************************************************/

function parallax(obj, property, start, end, duration, easing) {
	duration = (typeof duration !== 'undefined') ? duration : '1.25s';
	easing = (typeof easing !== 'undefined') ? easing : 'ease-out';
	var oParallax = {obj:obj, prop:property, start:parseInt(start), end:parseInt(end), percent:start.indexOf('%')!=-1 || end.indexOf('%')!=-1};
	obj.style.transition = property+' '+duration+' '+easing;
	aParallax.push(oParallax);
}

function onPageScroll(e) {
//	console.log('onPageScroll', e.scrollVertical*100+'%');	
	for (var p=0; p<aParallax.length; p++) {
		var oParallax = aParallax[p];
			oParallax.obj.style[oParallax.prop] = oParallax.start + e.scrollVertical*(oParallax.end - oParallax.start) + (oParallax.percent?'%':'');	
	}
}

function setPRConfiguration(config) {
	sendMessage("setPRConfiguration", config);
	
	// add touchmove event listener to body so we can know if user is touching and moving the ad
	document.body.addEventListener("touchmove", function(e) {
		sendMessage("userIsMoving", {});
	}, false);	
}

function setPRCallback(params) {
	sendMessage("setPRCallback", params);
}

window.addEventListener("message", function(event) {
	var data = JSON.parse(event.data);
	if(data.type === "ebCallbackFunction") {
		var func = eval(data.data.functionName);
		if(typeof func === "function") {
			func(data.data.parameters);
		}
	} else if (data.type == 'parallaxEnabled') {
		clearTimeout(timeout);
		revertFromGracefulFail();
	}//else if (data.type == "VISIBILITY_CHECK") {
//		handleParallax(data.data);
//	else console.log('ad recieved message of unknown type:', data.type, data.data);
}, false);

function setCreativeVersion() {
	sendMessage("setCreativeVersion", {
		creativeId: creativeId,
		creativeVersion: creativeVersion,
		creativeLastModified: lastModified,
		uid: uid
	});
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {
	if(!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if(listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function eventManager(event) {
	var msg;
	if(typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);
	} else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if(msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch(msg.type) {
		case "sendCreativeId":
			creativeIFrameId = msg.data.creativeIFrameId;
			addCustomScriptEventListener('pageScroll', onPageScroll);
			sendMessage("dispatchScrollPos", {
				uid: uid
			});
			if(creativeContainerReady)
				creativeContainerReady();
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for(var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if(!t) continue;
					t.callback(msg.data);
				}
				catch(e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function () {
	try {
		eventManager.apply(this, arguments);
	}
	catch(e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);